@@ -654,7 +654,8 @@ class config(object):
             print ('WARNING: version difference between %s [%s] and %s [%s]' % (self.docl[0][0],self.version,thisdoc,vl[0].text) )
         else:
           self.version = vl[0].text
-        self.parent_map = dict((c, p) for p in root.getiterator() for c in p)
+        ### replaced getiterator with iter
+        self.parent_map = dict((c, p) for p in root.iter() for c in p)
       else:
         if self.strings:
           self.contentDoc = xml.dom.minidom.parseString( self.vsamp  )
